package com.acme.m6a8.web.internal.commerce.discount.rule.type;

import com.liferay.commerce.context.CommerceContext;
import com.liferay.commerce.discount.model.CommerceDiscountRule;
import com.liferay.commerce.discount.rule.type.CommerceDiscountRuleType;
import com.liferay.commerce.model.CommerceOrder;
import com.liferay.commerce.model.CommerceOrderItem;
import com.liferay.portal.kernel.exception.PortalException;
import com.liferay.portal.kernel.language.LanguageUtil;
import com.liferay.portal.kernel.util.GetterUtil;
import com.liferay.portal.kernel.util.ResourceBundleUtil;

import java.util.List;
import java.util.Locale;
import java.util.ResourceBundle;

import org.osgi.service.component.annotations.Component;

@Component(
	property = {
		"commerce.discount.rule.type.key=m6a8",
		"commerce.discount.rule.type.order:Integer=51"
	},
	service = CommerceDiscountRuleType.class
)
public class M6A8CommerceDiscountRuleTypeImpl
	implements CommerceDiscountRuleType {

	@Override
	public boolean evaluate(
			CommerceDiscountRule commerceDiscountRule,
			CommerceContext commerceContext)
		throws PortalException {

		CommerceOrder commerceOrder = commerceContext.getCommerceOrder();

		if (commerceOrder == null) {
			return false;
		}

		List<CommerceOrderItem> commerceOrderItems =
			commerceOrder.getCommerceOrderItems();

		int mininumNumberOfItems = GetterUtil.getInteger(
			commerceDiscountRule.getSettingsProperty(
				commerceDiscountRule.getType()));

		if (commerceOrderItems.size() >= mininumNumberOfItems) {
			return true;
		}

		return false;
	}

	@Override
	public String getKey() {
		return "m6a8";
	}

	@Override
	public String getLabel(Locale locale) {
		ResourceBundle resourceBundle = ResourceBundleUtil.getBundle(
			"content.Language", locale, getClass());

		return LanguageUtil.get(
			resourceBundle, "has-a-minimum-number-of-items");
	}

	@Override
	public boolean validate(String typeSettings) {
		return true;
	}

}